package com.malk.ruisi.controller;

import cn.hutool.http.HttpUtil;
import com.malk.ruisi.service.RSService;
import com.malk.ruisi.service.impl.RSImplService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * @EnableScheduling 开启定时任务 [配置参考McScheduleTask]
 */
@Slf4j
@Configuration
@EnableScheduling
@ConditionalOnProperty(name = {"enable.scheduling"})
public class RSScheduleTask {

    @Autowired
    private RSService rsService;

    /**
     * 每天凌晨5点同步
     */
    @Scheduled(cron = "0 0 5 * * ? ")
    public void syncDingTalkFailedList() {
        try {
            rsService.syncDingTalk_exclusive();
        } catch (Exception e) {
            // 记录错误信息
            e.printStackTrace();
        }
    }
    /**
     * 每天凌晨6点同步
     * 删除供应商账号
     */
    @Scheduled(cron = "0 0 6 * * ? ")
//    @Scheduled(cron = "0 0/3 * * * ?")
    public void syncDingTalkFailedListDelect() {
        try {
            rsService.syncDingTalk_delect();
        } catch (Exception e) {
            // 记录错误信息
            e.printStackTrace();
        }
    }
//    /// 数据缓存 + 图片缓存, 10 分钟更新一次
    private Map portal_cache = new HashMap();

//    @Scheduled(cron = "0 0 5 * * ? ")
    @Scheduled(cron = "0 */5 * * * ?")
    public void hzmhByType() {
        log.info("定时刷新工作台开始：{}", LocalDateTime.now());
        try {
            rsService.getDataList();
//            HttpUtil.get("http://aservice.risechina.com:9020/ruisi/hzmh/byType");
//            portal_cache = new HashMap();
//            rsService.getPortalList("财务专区");
//            rsService.getPortalList("公司头条");
//            rsService.getPortalList("企业文化");
//            rsService.getPortalList("员工自助");
//            rsService.getPortalList("规章制度");

        } catch (Exception e) {
            // 记录错误信息
            e.printStackTrace();
        }
    }
}